**************************
* Regression code for Beer data
* This code can be use to obtain the estimates relying only on publicly available ratings data
**************************

use BeerDataForRegs56




*****************
* Create Data Labels for Output
*****************
	label var rtg "Ratings"
	label var rtg_ad "Ratings * Ad"
	label var price "Price"
	label var priceother "Price * Other"
	label var feature "Feature"
	label var display "Display"
	
*****************
* Begin Regressions
*****************
	local window = 8
	local top56 = 56

******************
** Create Figure 3 and 4 (weekly regressions)
******************
	forvalues wknum = 1 (1)20 {
	 xi: xtreg   RevHH rtg_ad rtg   i.beeryear if superweek==`wknum' , fe i(branddma) cluster(dma)
	        outreg2 rtg_ad          using RevBeerByWk`top56'.txt, ti(Summary Regressions of Superbowl Ratings) ctitle(Weeks `wknum' ) label  nocon  dec(3) 2aster keep(rtg_ad)
	 xi: xtreg   v72HH rtg_ad rtg   i.beeryear if superweek==`wknum' , fe i(branddma) cluster(dma)
	        outreg2 rtg_ad          using v72BeerByWk`top56'.txt, ti(Summary Regressions of Superbowl Ratings) ctitle(Weeks `wknum' ) label  nocon  dec(3) 2aster keep(rtg_ad)
	}




*****************
* Create Table 2
*****************
	preserve
	keep if superweek==0
		xi: xtreg   v72HH rtg                                              i.beeryear if beerbnum==1 , fe i(branddma) cluster(dma)
	     outreg2                                                      using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud )   nocon  dec(3) 2aster       keep(rtg) replace label
		xi: xtreg   v72HH rtg       price feature display   i.beeryear if beerbnum==1 , fe i(branddma) cluster(dma)
	     outreg2        rtg       price feature display   using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud )   nocon  dec(3) 2aster               keep(rtg   price feature display) label
		xi: xtreg   v72HH        rtg                                          i.beeryear if beerbnum~=1 , fe i(branddma) cluster(dma)
	     outreg2               rtg                                          using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster        keep( rtg ) label
		xi: xtreg   v72HH        rtg   price priceother feature display   i.beeryear if beerbnum~=1 , fe i(branddma) cluster(dma)
	     outreg2               rtg   price priceother feature display   using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster        keep(rtg   price priceother feature display) label
		xi: xtreg   v72HH rtg rtg_ad                                          i.beeryear, fe i(branddma) cluster(dma)
	     outreg2        rtg rtg_ad                                          using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All )   nocon  dec(3) 2aster            keep(rtg rtg_ad ) label
		xi: xtreg   v72HH rtg rtg_ad   price priceother feature display   i.beeryear, fe i(branddma) cluster(dma)                                                                                            
	       outreg2      rtg rtg_ad   price priceother feature display   using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All )   nocon  dec(3) 2aster keep(rtg rtg_ad   price priceother feature display) label
	restore


*****************
* Create Tables 4 & 5
*****************
	preserve
	drop if superweek>`window'
		*Table 4(1)
			xi: xtreg   v72HH rtg_ad  i.superweek          i.beeryear  if beerbnum==1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad            using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud Only )   nocon  dec(3) 2aster replace keep(rtg_ad ) label
		*Table 4(2)
			xi: xtreg   v72HH rtg_ad  i.superweek            price priceother feature display   i.beeryear if beerbnum==1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad              price priceother feature display   using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud Only )   nocon  dec(3) 2aster keep(rtg_ad              price priceother feature display) label

		*Table 5(1)
			xi: xtreg   RevHH rtg_ad  i.superweek          i.beeryear  if beerbnum==1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad            using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud Only)   nocon  dec(3) 2aster replace keep(rtg_ad ) label
		*Table 5(2)
			xi: xtreg   RevHH rtg_ad  i.superweek           price priceother feature display   i.beeryear if beerbnum==1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad              price priceother feature display   using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud Only )   nocon  dec(3) 2aster keep(rtg_ad              price priceother feature display ) label
	
	restore
	
	preserve
	drop if superweek>`window'
		*Table 4(3)
			xi: xtreg   v72HH             rtg   i.superweek i.beeryear   if beerbnum~=1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2                    rtg   using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster keep(rtg) label
		*Table 4(4)
			xi: xtreg   v72HH             rtg     price priceother feature display i.beeryear  i.superweek if beerbnum~=1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2                    rtg     price priceother feature display using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster keep(rtg     price priceother feature display) label
		*Table 4(5)
			xi: xtreg   v72HH rtg_ad rtg   i.superweek i.beeryear   if superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad rtg   using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands )   nocon  dec(3) 2aster keep(rtg_ad rtg) label
		*Table 4(6)
			xi: xtreg   v72HH rtg_ad rtg     price priceother feature display  i.superweek  i.beeryear if superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad rtg     price priceother feature display   using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands )   nocon  dec(3) 2aster keep(rtg_ad rtg     price priceother feature display) label

		*Table 5(3)
			xi: xtreg   RevHH             rtg   i.superweek i.beeryear  if beerbnum~=1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2                    rtg   using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster keep(rtg) label
		*Table 5(4)
			xi: xtreg   RevHH             rtg     price priceother feature display  i.superweek i.beeryear  if beerbnum~=1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2                    rtg     price priceother feature display using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster keep(rtg     price priceother feature display) label
		*Table 5(5)
			xi: xtreg   RevHH rtg_ad rtg   i.superweek i.beeryear  i.superweek if superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad rtg   using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands )   nocon  dec(3) 2aster keep(rtg_ad rtg) label
		*Table 5(6)
			xi: xtreg   RevHH rtg_ad rtg     price priceother feature display   i.superweek i.beeryear if superweek>0, fe i(branddma) cluster(dma) 
	       outreg2        rtg_ad rtg     price priceother feature display   using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands )   nocon  dec(3) 2aster keep(rtg_ad rtg   price priceother feature display) label
	restore


	