set more off

use "C:\Google Drive\SuperbowlShare\StataData\NielsenSalesBeer56"

	local window = 20
	keep if superweek<=`window'


*******************************
* Normalize all ratings numbers to fractions of population
*******************************
	replace rtg = rtg/100
	replace rtg_ad = rtg_ad/100
*	replace PostGRPs = PostGRPs/100
*	replace NFLgrps = NFLgrps/100
*	replace rtgNCAA = rtgNCAA/100


*******************************
* Setting the panel structure of data
*******************************
	* Long dimension: brand, market and week is primary dimension
	* Short dimension: Time series variation is across years to allow for year over year effects at the week level
		gen idvar=beerbnum*100000+dma*100+(superweek+5)
		label variable idvar "Brand DMA Week"
	* Set panel structure for Stata
		xtset idvar year

	* Also need fixed effects to account for brand performance in a given year
		gen beeryear=beerbnum*10000+year

*******************************
* Scale dependent variables by Num Households so DMAs are comparable
*******************************
	gen v72HH = (volume/72)/households
	gen RevHH = (price*volume)/households

*******************************
* Allow price effect to be different for aggregated category
*******************************
	* Variation in this price reflects variation in composition of category
	gen priceother=price*(topbrand=="OTHERBEER")
	label variable priceother "Price * OtherBrands"


* NCAA ratings are included to test for sports connection
* Need to interact ratings for NCAA tournament with SB ratings, SB ratings and Bud, and just Bud in case they perform differently during tournament
*	gen NCAArtg = rtg*rtgNCAA
*	gen NCAArtg_ad = rtg_ad*rtgNCAA
*	gen NCAAbud = rtgNCAA*(beerbnum==1)

*Dropping DMAs with avg revenue per HH less than .01 in any year given year.
*keep if top56
drop if dma==600 | dma==632 | dma==636 | dma==651 | dma==658 | dma==676 
drop if dma==724 | dma==759 | dma==705 | dma==749 | dma==516
drop if dma==529 & year==2009
replace top56=1 if dma==630

* The following scaling is for better interpretation of coefficients
*	replace PostGRPs = PostGRPs/100
*	replace NFLgrps = NFLgrps/100


save BeerDataForRegs56, replace
