set more off

use "C:\Google Drive\SuperbowlShare\StataData\NielsenSalesSoda56"



* Normalize all ratings numbers to fractions of population
	replace rtg = rtg/100
	replace rtg_ad = rtg_ad/100
*	replace PostGRPs = PostGRPs/100
*	replace NFLgrps = NFLgrps/100
*	replace rtgNCAA = rtgNCAA/100


* Setting the panel structure of data
	* Long dimension: brand, market and week is primary dimension
	* Short dimension: Time series variation is across years to allow for year over year effects at the week level
		gen idvar=sodabnum*100000+dma*100+(superweek+5)
		*gen idvar0=sodabnum*100000+dma*100+week0
		label variable idvar "Brand DMA Week"
	* Set panel structure for Stata
		xtset idvar year

	* Also need fixed effects to account for brand performance in a given year
		gen sodayear=sodabnum*10000+year

* Scale dependent variables by Num Households so DMAs are comparable
	gen v72HH = (volume/72)/households
	gen RevHH = (price*volume)/households

* Allow price effect to be different for aggregated category
	* Variation in this price reflects variation in composition of category
		gen priceother=price*(topbrand=="OTHER")
		label variable priceother "Price * OtherBrands"


* In some cases, we wanted to ignore Dr. Pepper's SB advertising
	*replace rtg_ad = 0 if (sodabnum==1)+(sodabnum==5) == 0
* We treat Pepsi's 2007 halftime show as if it were an ad
	replace rtg_ad = rtg if (year==2007)*(topbrand=="PEPSI")
* Differential Ad Effect when competitor also in the game
	gen rtg_ad_both    = rtg_ad*(  (year==2010) + (year==2006)  ==0)   * ( (topbrand=="COCA-COLA") + (topbrand=="PEPSI") ==1)          



* NCAA ratings are included to test for sports connection
* Need to interact ratings for NCAA tournament with SB ratings, SB ratings and Bud, and just Bud in case they perform differently during tournament
*	gen NCAArtg = rtg*rtgNCAA
*	gen NCAArtg_ad = rtg_ad*rtgNCAA
*	gen NCAArtg_ad_both = rtg_ad_both*rtgNCAA
*	gen NCAACoke = rtgNCAA*(sodabnum==1)
*	gen NCAAPepsi = rtgNCAA*(sodabnum==5)


gen Coke=sodabnum==1
gen Pepsi=sodabnum==5
gen top2 = 1*(sodabnum==1)+2*(sodabnum==5)

* The following scaling is for better interpretation of coefficients
*replace PostGRPs = PostGRPs/100
*replace NFLgrps = NFLgrps/100

save SodaDataForRegs56, replace
