**************************
* Regression code for Soda data
* This code can be use to obtain the estimates relying only on publicly available ratings data
**************************





use SodaDataForRegs56
set more off


	
***********************
* Additional ratings interactions to show Coke and Pepsi movement w/ SB viewership separately from each other ... whether advertising or not 
*  Needed for Table 3 which was added during revisions
***********************
	gen rtgCoke=rtg*(sodabnum==1)
	gen rtgPepsi=rtg*(sodabnum==5)
	gen rtg_adCoke=rtg_ad*(sodabnum==1)
	gen rtg_adPepsi=rtg_ad*(sodabnum==5)
	

*****************
* Create Data Labels for Output
*****************
	label var rtg "Ratings"
	label var rtg_ad "Ratings * Ad"
	label var rtg_ad_both "Ratings * Ad*Ad"
	label var price "Price"
	label var priceother "Price * Other"
	label var feature "Feature"
	label var display "Display"


	label var rtg_adCoke "Ratings * Ad * Coke"
	label var rtgCoke "Ratings * Coke"
	label var rtg_adPepsi "Ratings * Ad * Pepsi"
	label var rtgPepsi "Ratings * Pepsi"


*****************
* Begin Regressions
*****************
	local top56 = 210


preserve
keep if superweek==0
	xi: xtreg   v72HH rtg_adCoke rtgCoke                                          i.sodayear if sodabnum==1 , fe i(branddma) cluster(dma)
     outreg2                                                            using Post`top56'Wk0SodaRegs.tex, ti(Dependent Variable: Volume per Household) ctitle(Coke )   nocon  dec(3) 2aster replace keep(rtg_adCoke rtgCoke) label
	xi: xtreg   v72HH rtg_adPepsi rtgPepsi                                          i.sodayear if sodabnum==5 , fe i(branddma) cluster(dma)
     outreg2                                                            using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Pepsi )   nocon  dec(3) 2aster  keep(rtg_adPepsi rtgPepsi) label
	xi: xtreg   v72HH rtg_adCoke rtgCoke   price feature display   i.sodayear if sodabnum==1 , fe i(branddma) cluster(dma)
     outreg2                                                             using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Coke )   nocon  dec(3) 2aster keep(rtg_adCoke rtgCoke   price feature display) label
	xi: xtreg   v72HH rtg_adPepsi rtgPepsi   price feature display   i.sodayear if sodabnum==5 , fe i(branddma) cluster(dma)
     outreg2                                                            using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Pepsi )   nocon  dec(3) 2aster keep(rtg_adPepsi rtgPeps   price feature display) label
	xi: xtreg   v72HH rtg_ad rtg                                          i.sodayear if sodabnum~=1 & sodabnum~=5 , fe i(branddma) cluster(dma)
     outreg2                                                            using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Not CokePepsi )   nocon  dec(3) 2aster keep( rtg_ad rtg ) label
	xi: xtreg   v72HH rtg_ad rtg   price priceother feature display   i.sodayear if sodabnum~=1 & sodabnum~=5 , fe i(branddma) cluster(dma)
     outreg2                                                             using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Not CokePepsi )   nocon  dec(3) 2aster keep(rtg_ad rtg   price priceother feature display) label
	xi: xtreg   v72HH rtg_adCoke rtgCoke rtg_adPepsi rtgPepsi rtg                                          i.sodayear, fe i(branddma) cluster(dma)
     outreg2                                                            using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All )   nocon  dec(3) 2aster keep(rtg_adCoke rtgCoke rtg_adPepsi rtgPepsi rtg ) label
	xi: xtreg   v72HH rtg_adCoke rtgCoke rtg_adPepsi rtgPepsi rtg_ad rtg   price priceother feature display   i.sodayear, fe i(branddma) cluster(dma)
       outreg2                                                          using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All )   nocon  dec(3) 2aster keep(rtg_adCoke rtgCoke rtg_adPepsi rtgPepsi rtg   price priceother feature display) label
restore

  

forvalues wknum = 1 (1)20 {
   xi:xtreg   RevHH rtg_ad rtg_ad_both rtg i.sodayear if superweek==`wknum' & ( (brandnum==5)+(brandnum==1)==1), fe i(branddma) cluster(dma)
         outreg2 rtg_ad_both rtg_ad rtg  using RevCokePepsiByWk`top56'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Weeks `wknum' ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg)
   xi:xtreg   v72HH rtg_ad rtg_ad_both rtg i.sodayear if superweek==`wknum' & ( (brandnum==5)+(brandnum==1)==1), fe i(branddma) cluster(dma)
         outreg2 rtg_ad_both rtg_ad rtg  using VolCokePepsiByWk`top56'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Weeks `wknum' ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg)
}

local window = 8

preserve
drop if superweek>`window'

		xi: xtreg   RevHH rtg_ad rtg_ad_both rtg i.superweek   i.sodayear           if (sodabnum==1 | sodabnum==5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg    using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg) replace
		xi: xtreg   RevHH rtg_ad rtg_ad_both rtg i.superweek   price  feature display   i.sodayear           if (sodabnum==1 | sodabnum==5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg    price  feature display   using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg    price  feature display )
		xi: xtreg   RevHH rtg_ad                  rtg i.superweek   i.sodayear           if (sodabnum~=1 & sodabnum~=5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad                  rtg    using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Not Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad                  rtg)
		xi: xtreg   RevHH rtg_ad                  rtg i.superweek   price priceother feature display   i.sodayear           if (sodabnum~=1 & sodabnum~=5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad                  rtg    price priceother feature display   using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Not Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad                  rtg    price priceother feature display)
		xi: xtreg   RevHH rtg_ad rtg_ad_both rtg i.superweek                                           i.sodayear           if  superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg                                            using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg )
		xi: xtreg   RevHH rtg_ad rtg_ad_both rtg i.superweek   price priceother feature display   i.sodayear           if  superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg    price priceother feature display   using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg    price priceother feature display)

		xi: xtreg   v72HH rtg_ad rtg_ad_both rtg i.superweek   i.sodayear           if (sodabnum==1 | sodabnum==5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg    using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg) replace
		xi: xtreg   v72HH rtg_ad rtg_ad_both rtg    price  feature display   i.sodayear           if (sodabnum==1 | sodabnum==5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg    price  feature display   using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg    price  feature display )
		xi: xtreg   v72HH rtg_ad                  rtg i.superweek   i.sodayear           if (sodabnum~=1 & sodabnum~=5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad                  rtg    using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Not Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad                  rtg) 
		xi: xtreg   v72HH rtg_ad                  rtg    price priceother feature display   i.sodayear           if (sodabnum~=1 & sodabnum~=5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad                  rtg    price priceother feature display   using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Not Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad                  rtg    price priceother feature display)
		xi: xtreg   v72HH rtg_ad rtg_ad_both rtg i.superweek                                           i.sodayear           if  superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg                                            using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg )
		xi: xtreg   v72HH rtg_ad rtg_ad_both rtg    price priceother feature display   i.sodayear           if  superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg    price priceother feature display   using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg    price priceother feature display)


restore


